mailr8171 - /branches/ave_noe/test_suite/unit_tests/_prompt/test_noe.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on December 09, 2008 - 11:06:
Author: bugman
Date: Tue Dec  9 11:06:01 2008
New Revision: 8171

URL: http://svn.gna.org/viewcvs/relax?rev=8171&view=rev
Log:
Renamed all the noe.read_constraints() references in the unit tests to 
noe.read_restraints().


Modified:
    branches/ave_noe/test_suite/unit_tests/_prompt/test_noe.py

Modified: branches/ave_noe/test_suite/unit_tests/_prompt/test_noe.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/ave_noe/test_suite/unit_tests/_prompt/test_noe.py?rev=8171&r1=8170&r2=8171&view=diff
==============================================================================
--- branches/ave_noe/test_suite/unit_tests/_prompt/test_noe.py (original)
+++ branches/ave_noe/test_suite/unit_tests/_prompt/test_noe.py Tue Dec  9 
11:06:01 2008
@@ -39,8 +39,8 @@
     noe_fns = Noe(fake_relax.fake_instance())
 
 
-    def test_read_constraints_argfail_file(self):
-        """The file arg test of the noe.read_constraints() user function."""
+    def test_read_restraints_argfail_file(self):
+        """The file arg test of the noe.read_restraints() user function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -49,11 +49,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxStrError, self.noe_fns.read_constraints, 
file=data[1])
+            self.assertRaises(RelaxStrError, self.noe_fns.read_restraints, 
file=data[1])
 
 
-    def test_read_constraints_argfail_dir(self):
-        """The dir arg test of the noe.read_constraints() user function."""
+    def test_read_restraints_argfail_dir(self):
+        """The dir arg test of the noe.read_restraints() user function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -62,11 +62,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrError, 
self.noe_fns.read_constraints, file='noes', dir=data[1])
+            self.assertRaises(RelaxNoneStrError, 
self.noe_fns.read_restraints, file='noes', dir=data[1])
 
 
-    def test_read_constraints_argfail_proton1_col(self):
-        """The proton1_col arg test of the noe.read_constraints() user 
function."""
+    def test_read_restraints_argfail_proton1_col(self):
+        """The proton1_col arg test of the noe.read_restraints() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -75,11 +75,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneIntError, 
self.noe_fns.read_constraints, file='noes', proton1_col=data[1])
+            self.assertRaises(RelaxNoneIntError, 
self.noe_fns.read_restraints, file='noes', proton1_col=data[1])
 
 
-    def test_read_constraints_argfail_proton2_col(self):
-        """The proton2_col arg test of the noe.read_constraints() user 
function."""
+    def test_read_restraints_argfail_proton2_col(self):
+        """The proton2_col arg test of the noe.read_restraints() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -88,11 +88,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneIntError, 
self.noe_fns.read_constraints, file='noes', proton2_col=data[1])
+            self.assertRaises(RelaxNoneIntError, 
self.noe_fns.read_restraints, file='noes', proton2_col=data[1])
 
 
-    def test_read_constraints_argfail_lower_col(self):
-        """The lower_col arg test of the noe.read_constraints() user 
function."""
+    def test_read_restraints_argfail_lower_col(self):
+        """The lower_col arg test of the noe.read_restraints() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -101,11 +101,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneIntError, 
self.noe_fns.read_constraints, file='noes', lower_col=data[1])
+            self.assertRaises(RelaxNoneIntError, 
self.noe_fns.read_restraints, file='noes', lower_col=data[1])
 
 
-    def test_read_constraints_argfail_upper_col(self):
-        """The upper_col arg test of the noe.read_constraints() user 
function."""
+    def test_read_restraints_argfail_upper_col(self):
+        """The upper_col arg test of the noe.read_restraints() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -114,11 +114,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneIntError, 
self.noe_fns.read_constraints, file='noes', upper_col=data[1])
+            self.assertRaises(RelaxNoneIntError, 
self.noe_fns.read_restraints, file='noes', upper_col=data[1])
 
 
-    def test_read_constraints_argfail_sep(self):
-        """The sep arg test of the noe.read_constraints() user function."""
+    def test_read_restraints_argfail_sep(self):
+        """The sep arg test of the noe.read_restraints() user function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -127,7 +127,7 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrError, 
self.noe_fns.read_constraints, file='noes', sep=data[1])
+            self.assertRaises(RelaxNoneStrError, 
self.noe_fns.read_restraints, file='noes', sep=data[1])
 
 
     def test_spectrum_type_argfail_spectrum_type(self):




Related Messages


Powered by MHonArc, Updated Tue Dec 09 13:40:02 2008